# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['swagger_codegen',
 'swagger_codegen.api',
 'swagger_codegen.api.adapter',
 'swagger_codegen.cli',
 'swagger_codegen.parsing',
 'swagger_codegen.render',
 'swagger_codegen.render.post_processors',
 'swagger_codegen.render.renderers']

package_data = \
{'': ['*'], 'swagger_codegen': ['templates/package_renderer/*']}

install_requires = \
['boltons>=20.2.1,<21.0.0',
 'click>=7.1.1,<8.0.0',
 'inflection>=0.5,<0.6',
 'jinja2>=2.11.1,<3.0.0',
 'multidict>=5,<6',
 'pydantic>=1.4,<2.0',
 'rich>=9.6.1,<10.0.0',
 'schemathesis==1.1.0',
 'toml>=0.10.0,<0.11.0',
 'typer>=0.3,<0.4']

extras_require = \
{'all': ['httpx', 'aiohttp', 'requests'],
 'async': ['httpx', 'aiohttp'],
 'sync': ['requests']}

entry_points = \
{'console_scripts': ['swagger_codegen = swagger_codegen.cli.main:app']}

setup_kwargs = {
    'name': 'swagger-codegen',
    'version': '0.1.31',
    'description': 'Generate API clients by parsing Swagger definitions',
    'long_description': '## Swagger codegen for Python\n![Continuous Integration](https://github.com/asyncee/swagger_codegen/workflows/Continuous%20Integration/badge.svg)\n\n### Installation\n\n```bash\npip install swagger-codegen\n```\n\n### Swagger version\n\nCurrently, only OpenApi 3.x (aka Swagger 3) is supported. \n\n### Usage example\n\n```\n# Generate Petstore Api client using \'petstore\' package name.\nswagger_codegen generate https://petstore3.swagger.io/api/v3/openapi.json petstore\n\npython\n\nPython 3.8.1 (default, Jan 23 2020, 13:58:52) \n[Clang 11.0.0 (clang-1100.0.33.16)] on darwin\nType "help", "copyright", "credits" or "license" for more information.\n\n>>> from petstore import new_client, Configuration\n>>> from swagger_codegen.api.adapter.requests import RequestsAdapter\n>>> from petstore.apis.user.createUser import User\n>>> client = new_client(RequestsAdapter(), Configuration(host="http://petstore3.swagger.io"))\n>>> pets = client.pet.findPetsByStatus()\n>>> print(pets)\n[Pet(category=Category(id=1, name=\'Dogs\'), id=69, name=\'aHldog\', photoUrls=[\'string\'], status=\'available\',...]\n```\n\nYou can see [example source code](https://github.com/asyncee/swagger_codegen/tree/master/example)\nfor [PetStore](http://petstore3.swagger.io/) Api in example directory of a project.\n\nYou can test example client with following command:\n\n```bash\n# Run from project directory.\npython -m example.petstore_example \n```\n\n### Code generators (also known as renderers)\n\nThere are two code generator strategies in project:\n\n1. Render client as usual python package via `PackageRenderer`\n2. Render client as installable python package via `InstallablePackageRenderer`\n\nYou can choose what renderer to use by specifying `renderer` key in `.swagger-codegen.toml`\nfile. Please see `.swagger-codegen.toml.example` for allowed values.\n\n### Known issues\n\n- Content of generated files differs run-to-run because each time functions or\n  data transfer objects ordered differently. Functionally clients stay the same, but\n  each time the code is generated there are a large diff generated by git.\n- Not fully Openapi compliant: the project was built to fulfill my personal needs:\n  a support for FastAPI-generated schemas, and I needed this feature quickly,\n  that is why there are too many large dependencies (`schemathesis`) and incompatibilities.\n  Anyway, I\'m looking forward to fixing this issues by time.\n- There are may be delays in reaction to issues due to small amount of free time\n  (however PR\'s with tests are merged asap).\n\n### Work in progress\n\nThough library gives nice results for generated API, it is still in development.\nSome tests are missing. API is a subject to change until stable release.\n\nAnyway backward compatibility will be kept as much as possible.\n\nThe code is not optimized yet and mostly dirty because the project was born\nas a holiday prototype.\n\nAlso `example` directory may be out of sync with actual generated code.\n\n### Contributors\n\nYou can see all people who helped this project [at the contributors page](https://github.com/asyncee/swagger_codegen/graphs/contributors)\n',
    'author': 'asyncee',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/asyncee/swagger_codegen',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
